"""
s3s3 version information.
"""
from subprocess import Popen, PIPE
from os.path import abspath, dirname


VERSION = (0, 1, 8, 'dev', 0)


def git_sha():
    loc = abspath(dirname(__file__))
    try:
        p = Popen(
            'cd \"%s\" && git log -1 --format=format:%%h' % loc,
            shell=True,
            stdout=PIPE,
            stderr=PIPE
        )
        return p.communicate()[0]
    except OSError:
        return None


def get_version(form='short'):
    """
    Returns the version string.
    Takes single argument ``form``, which should be one of the following
    strings:

    * ``short`` Returns major + minor branch version string with the format of
    B.b.t.
    * ``normal`` Returns human readable version string with the format of
    B.b.t _type type_num.
    * ``verbose`` Returns a verbose version string with the format of
    B.b.t _type type_num@git_sha
    * ``all`` Returns a dict of all versions.
    """
    versions = {}
    branch = '%s.%s' % (VERSION[0], VERSION[1])
    tertiary = VERSION[2]
    type_ = VERSION[3]
    type_num = VERSION[4]
    versions['branch'] = branch
    v = versions['branch']
    if tertiary:
        versions['tertiary'] = '.' + str(tertiary)
        v += versions['tertiary']
    versions['short'] = v
    if form is 'short':
        return v
    v += " " + type_ + ' ' + str(type_num)
    versions['normal'] = v
    if form is 'normal':
        return v
    v += ' @' + git_sha()
    versions['verbose'] = v
    if form is 'verbose':
        return v
    if form is 'all':
        return versions



"""
Logging for s3s3.
"""
import logging


format = '%(asctime)s %(name)s-%(levelname)s '\
         '[%(pathname)s %(lineno)d] %(message)s'


PATHS = ['/var/log/s3s3/s3s3.log',
         '/tmp/s3s3.log']


def get_filename():
    """
    Try to open log files from the PATHS list, the first log file
    path that is successful is returned.
    """
    for path in PATHS:
        try:
            with open(path, 'a+') as f:
                return path
        except Exception:
            pass
    Exception('Unable to create logfile.')


logging.basicConfig(level=logging.INFO,
                    format=format,
                    filename=get_filename(),
                    filemode='a+')


logger = logging.getLogger()



#!/usr/bin/env python
"""
Duplicate a source s3 bucket to destination s3 buckets.

Configuration template:
https://github.com/lsst-squre/s3s3/blob/master/s3s3/s3s3.ini.dist

Also: https://github.com/lsst-sqre/s3s3
"""
import argparse

from s3s3.client import BucketClient
from s3s3.config import initialize
from s3s3.log import logger


def duplicate():
    """
    Subscribe to 'backup' redis pubsub channel and listen (a
    blocking call).
    """
    try:
        bc = BucketClient()
        bc.duplicate()
    except KeyboardInterrupt:
        return True
    except Exception as e:
        logger.warning(e)
        return False


def main():
    parser = argparse.ArgumentParser(description=__doc__)
    parser.add_argument('--config', type=str,
                        help='Configuration file to use.')
    args = parser.parse_args()
    if args.config:
        initialize(args.config)
    if duplicate():
        exit(0)
    else:
        exit(1)


if __name__ == "__main__":
    main()



import os
import setuptools
from s3s3.version import get_version

readme = open('README.md').read()
requirements = open('requirements.txt').read().split('\n')

long_description = """
s3s3 %s
A microservice to move files from S3 APIs (Swift or Ceph) to other S3 APIs.

To install use `pip install s3s3`

----

%s

----

For more information, please see: https://github.com/lsst-sqre/s3s3
""" % (get_version('short'), readme)

setuptools.setup(
    name='s3s3',
    version=get_version('short'),
    author='jmatt',
    author_email='jmatt@lsst.org',
    description='A microservice to move files from S3 APIs (Swift or '
                'Ceph) to other S3 APIs.',
    long_description=long_description,
    url='https://github.com/lsst-sqre/s3s3',
    packages=setuptools.find_packages(),
    install_requires=requirements,
    classifiers=[
        'Development Status :: 4 - Beta',
        'Intended Audience :: Developers',
        'Intended Audience :: Information Technology',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
        'Topic :: Software Development :: Libraries',
        'Topic :: System',
        'Topic :: System :: Archiving :: Backup',
        'Topic :: System :: Systems Administration'
    ],
    data_files=[('extras', ['extras/s3s3.conf', 'extras/s3s3.ini.dist'])],
    entry_points={
        'console_scripts': [
            's3s3listen = s3s3.scripts.listen:main',
            's3s3bucket = s3s3.scripts.bucket:main',
            'echo_s3s3_ini_template = '
            's3s3.scripts.echo_s3s3_ini_template:main',
            'echo_s3s3_supervisord_conf = '
            's3s3.scripts.echo_s3s3_supervisord_conf:main'
        ]
    })



#!/usr/bin/env python
"""
Echo the s3s3 configuration template.
"""
from pkg_resources import Requirement, resource_string


def try_resource(location):
    """
    Try to get the resource in ``location``.
    """
    try:
        return resource_string(Requirement.parse('s3s3'), location)
    except FileNotFoundError:
        return ''


def echo():
    """
    Echo the s3s3 configuration file in.

    Use pkg_resources module to try to find the s3s3.ini.dist configuration
    file. The file is located in a different location depending on if it's
    a sdist or bdist_wheel install.
    """
    try:
        conf = try_resource('extras/s3s3.ini.dist')  # sdist
        if not conf:
            conf = try_resource('../../../extras/s3s3.ini.dist')  # bdist
        print(conf.decode('utf-8'))
        return True
    except Exception as e:
        return False


def main():
    if echo():
        exit(0)
    else:
        exit(1)


if __name__ == "__main__":
    main()
